==> libebml-0.8.0.tar.bz2: libebml-0.8.0/ebml/EbmlDummy.h <==
/****************************************************************************
** libebml : parse EBML files, see http://embl.sourceforge.net/
**
** <file/class description>
**
** Copyright (C) 2002-2010 Steve Lhomme.  All rights reserved.
**
** This file is part of libebml.
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Lesser General Public
** License as published by the Free Software Foundation; either
** version 2.1 of the License, or (at your option) any later version.
** 
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Lesser General Public License for more details.
** 
** You should have received a copy of the GNU Lesser General Public
** License along with this library; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.
**
** Contact license@matroska.org if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

/*!
	\file
	\version \$Id: EbmlDummy.h 639 2004-07-09 20:59:14Z mosu $
	\author Steve Lhomme     <robux4 @ users.sf.net>
*/
#ifndef LIBEBML_DUMMY_H
#define LIBEBML_DUMMY_H

#include "EbmlBinary.h"

START_LIBEBML_NAMESPACE

class EBML_DLL_API EbmlDummy : public EbmlBinary {
	public:
		EbmlDummy() :DummyId(DummyRawId)  {}
		EbmlDummy(const EbmlId & aId) :EbmlBinary(), DummyId(aId) {}
		EbmlDummy(const EbmlDummy & ElementToClone):EbmlBinary(ElementToClone), DummyId(ElementToClone.DummyId) {}

		bool IsDummy() const {return true;}
		bool IsDefaultValue() const {return true;}

#if defined(EBML_STRICT_API)
    private:
#else
    protected:
#endif
		const EbmlId DummyId;
		static const EbmlId DummyRawId;

        EBML_CONCRETE_CLASS(EbmlDummy)
};

END_LIBEBML_NAMESPACE

#endif // LIBEBML_DUMMY_H

==> libebml_1.3.0.orig.tar.bz2: libebml-1.3.0/ebml/EbmlDummy.h <==
/****************************************************************************
** libebml : parse EBML files, see http://embl.sourceforge.net/
**
** <file/class description>
**
** Copyright (C) 2002-2010 Steve Lhomme.  All rights reserved.
**
** This file is part of libebml.
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Lesser General Public
** License as published by the Free Software Foundation; either
** version 2.1 of the License, or (at your option) any later version.
** 
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Lesser General Public License for more details.
** 
** You should have received a copy of the GNU Lesser General Public
** License along with this library; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.
**
** Contact license@matroska.org if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

/*!
	\file
	\version \$Id$
	\author Steve Lhomme     <robux4 @ users.sf.net>
*/
#ifndef LIBEBML_DUMMY_H
#define LIBEBML_DUMMY_H

#include "EbmlBinary.h"

START_LIBEBML_NAMESPACE

class EBML_DLL_API EbmlDummy : public EbmlBinary {
	public:
		EbmlDummy() :DummyId(DummyRawId) {}
		EbmlDummy(const EbmlId & aId) :EbmlBinary(), DummyId(aId) {}
		EbmlDummy(const EbmlDummy & ElementToClone):EbmlBinary(ElementToClone), DummyId(ElementToClone.DummyId) {}

		bool IsDummy() const {return true;}
		bool IsDefaultValue() const {return true;}

        virtual operator const EbmlId &() const {
            return DummyId;
        }

#if defined(EBML_STRICT_API)
    private:
#else
    protected:
#endif
		const EbmlId DummyId;
		static const EbmlId DummyRawId;

        EBML_CONCRETE_DUMMY_CLASS(EbmlDummy)
};

END_LIBEBML_NAMESPACE

#endif // LIBEBML_DUMMY_H
